package com.ruoyi.system.service;

import java.util.Date;
import java.util.List;
import com.ruoyi.system.domain.PostNotice;


/**
 * 公告Service接口
 *
 * @author ruoyi
 * @date 2023-01-14
 */
public interface IPostNoticeService
{
    /**
     * 查询公告
     *
     * @param noticeId 公告主键
     * @return 公告
     */
    public PostNotice selectPostNoticeByNoticeId(Long noticeId);

    /**
     * 查询公告列表
     *
     * @param postNotice 公告
     * @return 公告集合
     */
    public List<PostNotice> selectPostNoticeList(PostNotice postNotice);

    /**
     * 新增公告
     *
     * @param postNotice 公告
     * @return 结果
     */
    public int insertPostNotice(PostNotice postNotice);

    /**
     * 修改公告
     *
     * @param postNotice 公告
     * @return 结果
     */
    public int updatePostNotice(PostNotice postNotice);

    /**
     * 批量删除公告
     *
     * @param noticeIds 需要删除的公告主键集合
     * @return 结果
     */
    public int deletePostNoticeByNoticeIds(Long[] noticeIds);

    /**
     * 删除公告信息
     *
     * @param noticeId 公告主键
     * @return 结果
     */
    public int deletePostNoticeByNoticeId(Long noticeId);

    /**
     * 查询公告详情
     * @param noticeId
     * @return
     */
    public String selectDetailByNoticeId(Long noticeId);
    //搜索公告列表
    public List<PostNotice> selectList(String title, Date noticeTimeLeft, Date noticeTimeRight);


}
